==> haskell-juicypixels-3.2.6.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-juicypixels/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.6.4
id: JuicyPixels-3.2.6.4-d8f2907dbe08e18df33cc18fff2945f3
key: Juicy_KDJzN34dFoj00WS4onRv8f
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.Gif
    Codec.Picture.Png Codec.Picture.Jpg Codec.Picture.HDR
    Codec.Picture.Tga Codec.Picture.Tiff Codec.Picture.Metadata
    Codec.Picture.Metadata.Exif Codec.Picture.Saving
    Codec.Picture.Types Codec.Picture.ColorQuant
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/JuicyPixels-3.2.6.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/JuicyPixels-3.2.6.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/JuicyPixels-3.2.6.4
hs-libraries: HSJuicyPixels-3.2.6.4-KDJzN34dFoj00WS4onRv8f
include-dirs: /usr/lib/ghc-7.10.3/site-local/JuicyPixels-3.2.6.4/include
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    primitive-0.6-e792418f7dbd95c8907334653976b3c4
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-juicypixels-3.2.7-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-juicypixels/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: JuicyPixels
version: 3.2.7
id: JuicyPixels-3.2.7-7a5ea2c8822f98f6d9837c143b0f3055
key: Juicy_JMgE8PBYSKHBOmusQuiyg6
license: BSD3
maintainer: vincent.berthoux@gmail.com
stability: Stable
homepage: https://github.com/Twinside/Juicy.Pixels
synopsis: Picture loading/serialization (in png, jpeg, bitmap, gif, tga, tiff and radiance)
description:
    <<data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAMAAAADABAMAAACg8nE0AAAAElBMVEUAAABJqDSTWEL/qyb///8AAABH/1GTAAAAAXRSTlMAQObYZgAAAN5JREFUeF7s1sEJgFAQxFBbsAV72v5bEVYWPwT/XDxmCsi7zvHXavYREBDI3XP2GgICqBBYuwIC+/rVayPUAyAg0HvIXBcQoDFDGnUBgWQQ2Bx3AYFaRoBpAQHWb3bt2ARgGAiCYFFuwf3X5HA/McgGJWI2FdykCv4aBYzmKwDwvl6NVmUAAK2vlwEALK7fo88GANB6HQsAAAAAAAAA7P94AQCzswEAAAAAAAAAAAAAAAAAAICzh4UAO4zWAYBfRutHA4Bn5C69JhowAMGoBaMWDG0wCkbBKBgFo2AUAACPmegUST/IJAAAAABJRU5ErkJggg==>>
    .
    This library can load and store images in PNG,Bitmap, Jpeg, Radiance, Tiff and Gif images.
category: Codec, Graphics, Image
author: Vincent Berthoux
exposed: True
exposed-modules:
    Codec.Picture Codec.Picture.Bitmap Codec.Picture.Gif
    Codec.Picture.Png Codec.Picture.Jpg Codec.Picture.HDR
    Codec.Picture.Tga Codec.Picture.Tiff Codec.Picture.Metadata
    Codec.Picture.Metadata.Exif Codec.Picture.Saving
    Codec.Picture.Types Codec.Picture.ColorQuant
hidden-modules: Codec.Picture.Jpg.DefaultTable
                Codec.Picture.Jpg.Metadata Codec.Picture.Jpg.FastIdct
                Codec.Picture.Jpg.FastDct Codec.Picture.Jpg.Types
                Codec.Picture.Jpg.Common Codec.Picture.Jpg.Progressive
                Codec.Picture.Gif.LZW Codec.Picture.Gif.LZWEncoding
                Codec.Picture.Png.Export Codec.Picture.Png.Type
                Codec.Picture.Png.Metadata Codec.Picture.Tiff.Metadata
                Codec.Picture.Tiff.Types Codec.Picture.BitWriter
                Codec.Picture.InternalHelper Codec.Picture.VectorByteConversion
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/JuicyPixels-3.2.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/JuicyPixels-3.2.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/JuicyPixels-3.2.7
hs-libraries: HSJuicyPixels-3.2.7-JMgE8PBYSKHBOmusQuiyg6
include-dirs: /usr/lib/ghc-7.10.3/site-local/JuicyPixels-3.2.7/include
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-juicypixels/html/JuicyPixels.haddock
haddock-html: /usr/share/doc/haskell-juicypixels/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
